# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/material_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import material_pb2 as eolymp_dot_course_dot_material__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/course/material_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/course/material.proto\x1a eolymp/wellknown/direction.proto\"S\n\x13\x43reateMaterialInput\x12)\n\x08material\x18\x01 \x01(\x0b\x32\x17.eolymp.course.Material\x12\x11\n\tmodule_id\x18\x02 \x01(\t\"+\n\x14\x43reateMaterialOutput\x12\x13\n\x0bmaterial_id\x18\x01 \x01(\t\"\xf4\x01\n\x13UpdateMaterialInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.course.UpdateMaterialInput.Patch\x12\x13\n\x0bmaterial_id\x18\x02 \x01(\t\x12)\n\x08material\x18\x03 \x01(\x0b\x32\x17.eolymp.course.Material\"d\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\t\n\x05\x44\x45PTH\x10\x05\x12\x0b\n\x07\x43ONTENT\x10\x06\x12\x0b\n\x07GRADING\x10\x07\"\x16\n\x14UpdateMaterialOutput\"e\n\x11MoveMaterialInput\x12\x13\n\x0bmaterial_id\x18\x01 \x01(\t\x12\x15\n\rnew_module_id\x18\x02 \x01(\t\x12\x11\n\tnew_index\x18\x03 \x01(\r\x12\x11\n\tnew_depth\x18\x04 \x01(\r\"\x14\n\x12MoveMaterialOutput\"*\n\x13\x44\x65leteMaterialInput\x12\x13\n\x0bmaterial_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteMaterialOutput\"n\n\x15\x44\x65scribeMaterialInput\x12\x13\n\x0bmaterial_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.course.Material.Extra\"C\n\x16\x44\x65scribeMaterialOutput\x12)\n\x08material\x18\x01 \x01(\x0b\x32\x17.eolymp.course.Material\"\xd0\x02\n\x12ListMaterialsInput\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.course.ListMaterialsInput.Filter\x12\x34\n\x04sort\x18\x32 \x01(\x0e\x32&.eolymp.course.ListMaterialsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.course.Material.Extra\x1a\x17\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\"\x11\n\x04Sort\x12\t\n\x05INDEX\x10\x00\"L\n\x13ListMaterialsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.course.Material2\xe5\x07\n\x0fMaterialService\x12\x97\x01\n\x0e\x43reateMaterial\x12\".eolymp.course.CreateMaterialInput\x1a#.eolymp.course.CreateMaterialOutput\"<\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0c\"\n/materials\x12\xa5\x01\n\x0eUpdateMaterial\x12\".eolymp.course.UpdateMaterialInput\x1a#.eolymp.course.UpdateMaterialOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a\x1a\x18/materials/{material_id}\x12\xa4\x01\n\x0cMoveMaterial\x12 .eolymp.course.MoveMaterialInput\x1a!.eolymp.course.MoveMaterialOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1f\"\x1d/materials/{material_id}/move\x12\xa5\x01\n\x0e\x44\x65leteMaterial\x12\".eolymp.course.DeleteMaterialInput\x1a#.eolymp.course.DeleteMaterialOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a*\x18/materials/{material_id}\x12\xaa\x01\n\x10\x44\x65scribeMaterial\x12$.eolymp.course.DescribeMaterialInput\x1a%.eolymp.course.DescribeMaterialOutput\"I\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1a\x12\x18/materials/{material_id}\x12\x93\x01\n\rListMaterials\x12!.eolymp.course.ListMaterialsInput\x1a\".eolymp.course.ListMaterialsOutput\";\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/materialsB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.material_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MATERIALSERVICE.methods_by_name['CreateMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['CreateMaterial']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\014\"\n/materials'
  _MATERIALSERVICE.methods_by_name['UpdateMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['UpdateMaterial']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\032\032\030/materials/{material_id}'
  _MATERIALSERVICE.methods_by_name['MoveMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['MoveMaterial']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\037\"\035/materials/{material_id}/move'
  _MATERIALSERVICE.methods_by_name['DeleteMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['DeleteMaterial']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\032*\030/materials/{material_id}'
  _MATERIALSERVICE.methods_by_name['DescribeMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['DescribeMaterial']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\032\022\030/materials/{material_id}'
  _MATERIALSERVICE.methods_by_name['ListMaterials']._options = None
  _MATERIALSERVICE.methods_by_name['ListMaterials']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/materials'
  _CREATEMATERIALINPUT._serialized_start=218
  _CREATEMATERIALINPUT._serialized_end=301
  _CREATEMATERIALOUTPUT._serialized_start=303
  _CREATEMATERIALOUTPUT._serialized_end=346
  _UPDATEMATERIALINPUT._serialized_start=349
  _UPDATEMATERIALINPUT._serialized_end=593
  _UPDATEMATERIALINPUT_PATCH._serialized_start=493
  _UPDATEMATERIALINPUT_PATCH._serialized_end=593
  _UPDATEMATERIALOUTPUT._serialized_start=595
  _UPDATEMATERIALOUTPUT._serialized_end=617
  _MOVEMATERIALINPUT._serialized_start=619
  _MOVEMATERIALINPUT._serialized_end=720
  _MOVEMATERIALOUTPUT._serialized_start=722
  _MOVEMATERIALOUTPUT._serialized_end=742
  _DELETEMATERIALINPUT._serialized_start=744
  _DELETEMATERIALINPUT._serialized_end=786
  _DELETEMATERIALOUTPUT._serialized_start=788
  _DELETEMATERIALOUTPUT._serialized_end=810
  _DESCRIBEMATERIALINPUT._serialized_start=812
  _DESCRIBEMATERIALINPUT._serialized_end=922
  _DESCRIBEMATERIALOUTPUT._serialized_start=924
  _DESCRIBEMATERIALOUTPUT._serialized_end=991
  _LISTMATERIALSINPUT._serialized_start=994
  _LISTMATERIALSINPUT._serialized_end=1330
  _LISTMATERIALSINPUT_FILTER._serialized_start=1288
  _LISTMATERIALSINPUT_FILTER._serialized_end=1311
  _LISTMATERIALSINPUT_SORT._serialized_start=1313
  _LISTMATERIALSINPUT_SORT._serialized_end=1330
  _LISTMATERIALSOUTPUT._serialized_start=1332
  _LISTMATERIALSOUTPUT._serialized_end=1408
  _MATERIALSERVICE._serialized_start=1411
  _MATERIALSERVICE._serialized_end=2408
# @@protoc_insertion_point(module_scope)
