# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/mailing/email_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/mailing/email_type.proto\x12\x0e\x65olymp.mailing*b\n\tEmailType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x01\x12\x0e\n\nNEWSLETTER\x10\x02\x12\x0b\n\x07UPDATES\x10\x03\x12\x0e\n\nCOMMERCIAL\x10\x04\x12\t\n\x05OTHER\x10\x05\x42\x31Z/github.com/eolymp/go-sdk/eolymp/mailing;mailingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.mailing.email_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/mailing;mailing'
  _EMAILTYPE._serialized_start=51
  _EMAILTYPE._serialized_end=149
# @@protoc_insertion_point(module_scope)
