# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/acl/entitlement_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/acl/entitlement_service.proto\x12\neolymp.acl\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\"\x1d\n\x1bIntrospectEntitlementsInput\"4\n\x1cIntrospectEntitlementsOutput\x12\x14\n\x0c\x65ntitlements\x18\x01 \x03(\t2\xaa\x01\n\x12\x45ntitlementService\x12\x93\x01\n\x16IntrospectEntitlements\x12\'.eolymp.acl.IntrospectEntitlementsInput\x1a(.eolymp.acl.IntrospectEntitlementsOutput\"&\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x11\x12\x0f/__entitlementsB)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.entitlement_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _ENTITLEMENTSERVICE.methods_by_name['IntrospectEntitlements']._options = None
  _ENTITLEMENTSERVICE.methods_by_name['IntrospectEntitlements']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\021\022\017/__entitlements'
  _INTROSPECTENTITLEMENTSINPUT._serialized_start=119
  _INTROSPECTENTITLEMENTSINPUT._serialized_end=148
  _INTROSPECTENTITLEMENTSOUTPUT._serialized_start=150
  _INTROSPECTENTITLEMENTSOUTPUT._serialized_end=202
  _ENTITLEMENTSERVICE._serialized_start=205
  _ENTITLEMENTSERVICE._serialized_end=375
# @@protoc_insertion_point(module_scope)
