# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/taxonomy/enum_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.taxonomy import enum_pb2 as eolymp_dot_taxonomy_dot_enum__pb2
from eolymp.taxonomy import enum_value_pb2 as eolymp_dot_taxonomy_dot_enum__value__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/taxonomy/enum_service.proto\x12\x0f\x65olymp.taxonomy\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/taxonomy/enum.proto\x1a eolymp/taxonomy/enum_value.proto\x1a!eolymp/wellknown/expression.proto\"6\n\x0f\x43reateEnumInput\x12#\n\x04\x65num\x18\x01 \x01(\x0b\x32\x15.eolymp.taxonomy.Enum\"#\n\x10\x43reateEnumOutput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\"\"\n\x0f\x44\x65leteEnumInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\"\x12\n\x10\x44\x65leteEnumOutput\"\x9a\x01\n\x0fUpdateEnumInput\x12\x35\n\x05patch\x18\x01 \x03(\x0e\x32&.eolymp.taxonomy.UpdateEnumInput.Patch\x12\x0f\n\x07\x65num_id\x18\x02 \x01(\t\x12#\n\x04\x65num\x18\x03 \x01(\x0b\x32\x15.eolymp.taxonomy.Enum\"\x1a\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\"\x12\n\x10UpdateEnumOutput\"$\n\x11\x44\x65scribeEnumInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\"9\n\x12\x44\x65scribeEnumOutput\x12#\n\x04\x65num\x18\x01 \x01(\x0b\x32\x15.eolymp.taxonomy.Enum\"\xde\x01\n\x0eListEnumsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.taxonomy.ListEnumsInput.Filter\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"F\n\x0fListEnumsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.taxonomy.Enum\"J\n\x10\x43reateValueInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.eolymp.taxonomy.Value\"%\n\x11\x43reateValueOutput\x12\x10\n\x08value_id\x18\x01 \x01(\t\"5\n\x10\x44\x65leteValueInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteValueOutput\"\xe0\x01\n\x10UpdateValueInput\x12\x36\n\x05patch\x18\x01 \x03(\x0e\x32\'.eolymp.taxonomy.UpdateValueInput.Patch\x12\x0f\n\x07\x65num_id\x18\x02 \x01(\t\x12\x10\n\x08value_id\x18\x03 \x01(\t\x12%\n\x05value\x18\x04 \x01(\x0b\x32\x16.eolymp.taxonomy.Value\"J\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x08\n\x04\x41\x42\x42R\x10\x02\x12\x0b\n\x07SUMMARY\x10\x03\x12\t\n\x05IMAGE\x10\x04\x12\x0c\n\x08KEYWORDS\x10\x05\"\x13\n\x11UpdateValueOutput\"G\n\x12\x44\x65scribeValueInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x64 \x01(\t\"<\n\x13\x44\x65scribeValueOutput\x12%\n\x05value\x18\x01 \x01(\x0b\x32\x16.eolymp.taxonomy.Value\"\x81\x02\n\x0fListValuesInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.taxonomy.ListValuesInput.Filter\x12\x0e\n\x06locale\x18\x64 \x01(\t\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"H\n\x10ListValuesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.taxonomy.Value\"\x81\x01\n\x13TranslateValueInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x37\n\x0btranslation\x18\x04 \x01(\x0b\x32\".eolymp.taxonomy.Value.Translation\"\x16\n\x14TranslateValueOutput\"K\n\x16\x44\x65leteTranslationInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\"\x19\n\x17\x44\x65leteTranslationOutput\"\xd4\x01\n\x15ListTranslationsInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.taxonomy.ListTranslationsInput.Filter\x1a:\n\x06\x46ilter\x12\x30\n\x06locale\x18\x01 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Z\n\x16ListTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".eolymp.taxonomy.Value.Translation2\xa2\x10\n\x0b\x45numService\x12\x8b\x01\n\nCreateEnum\x12 .eolymp.taxonomy.CreateEnumInput\x1a!.eolymp.taxonomy.CreateEnumOutput\"8\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x08\"\x06/enums\x12\x95\x01\n\nDeleteEnum\x12 .eolymp.taxonomy.DeleteEnumInput\x1a!.eolymp.taxonomy.DeleteEnumOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12*\x10/enums/{enum_id}\x12\x95\x01\n\nUpdateEnum\x12 .eolymp.taxonomy.UpdateEnumInput\x1a!.eolymp.taxonomy.UpdateEnumOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12\x1a\x10/enums/{enum_id}\x12\x80\x01\n\x0c\x44\x65scribeEnum\x12\".eolymp.taxonomy.DescribeEnumInput\x1a#.eolymp.taxonomy.DescribeEnumOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x12\x12\x10/enums/{enum_id}\x12m\n\tListEnums\x12\x1f.eolymp.taxonomy.ListEnumsInput\x1a .eolymp.taxonomy.ListEnumsOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/enums\x12\x9e\x01\n\x0b\x43reateValue\x12!.eolymp.taxonomy.CreateValueInput\x1a\".eolymp.taxonomy.CreateValueOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18\"\x16/enums/{enum_id}/items\x12\xaa\x01\n\x0b\x44\x65leteValue\x12!.eolymp.taxonomy.DeleteValueInput\x1a\".eolymp.taxonomy.DeleteValueOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$*\"/enums/{enum_id}/values/{value_id}\x12\xaa\x01\n\x0bUpdateValue\x12!.eolymp.taxonomy.UpdateValueInput\x1a\".eolymp.taxonomy.UpdateValueOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\x1a\"/enums/{enum_id}/values/{value_id}\x12\x95\x01\n\rDescribeValue\x12#.eolymp.taxonomy.DescribeValueInput\x1a$.eolymp.taxonomy.DescribeValueOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02$\x12\"/enums/{enum_id}/values/{value_id}\x12\x80\x01\n\nListValues\x12 .eolymp.taxonomy.ListValuesInput\x1a!.eolymp.taxonomy.ListValuesOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x18\x12\x16/enums/{enum_id}/items\x12\xc9\x01\n\x0eTranslateValue\x12$.eolymp.taxonomy.TranslateValueInput\x1a%.eolymp.taxonomy.TranslateValueOutput\"j\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02:\x1a\x38/enums/{enum_id}/values/{value_id}/translations/{locale}\x12\xd2\x01\n\x11\x44\x65leteTranslation\x12\'.eolymp.taxonomy.DeleteTranslationInput\x1a(.eolymp.taxonomy.DeleteTranslationOutput\"j\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02:*8/enums/{enum_id}/values/{value_id}/translations/{locale}\x12\xab\x01\n\x10ListTranslations\x12&.eolymp.taxonomy.ListTranslationsInput\x1a\'.eolymp.taxonomy.ListTranslationsOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x31*//enums/{enum_id}/values/{value_id}/translationsB3Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.taxonomy.enum_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomy'
  _ENUMSERVICE.methods_by_name['CreateEnum']._options = None
  _ENUMSERVICE.methods_by_name['CreateEnum']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\010\"\006/enums'
  _ENUMSERVICE.methods_by_name['DeleteEnum']._options = None
  _ENUMSERVICE.methods_by_name['DeleteEnum']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\022*\020/enums/{enum_id}'
  _ENUMSERVICE.methods_by_name['UpdateEnum']._options = None
  _ENUMSERVICE.methods_by_name['UpdateEnum']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\022\032\020/enums/{enum_id}'
  _ENUMSERVICE.methods_by_name['DescribeEnum']._options = None
  _ENUMSERVICE.methods_by_name['DescribeEnum']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\022\022\020/enums/{enum_id}'
  _ENUMSERVICE.methods_by_name['ListEnums']._options = None
  _ENUMSERVICE.methods_by_name['ListEnums']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\010\022\006/enums'
  _ENUMSERVICE.methods_by_name['CreateValue']._options = None
  _ENUMSERVICE.methods_by_name['CreateValue']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\030\"\026/enums/{enum_id}/items'
  _ENUMSERVICE.methods_by_name['DeleteValue']._options = None
  _ENUMSERVICE.methods_by_name['DeleteValue']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002$*\"/enums/{enum_id}/values/{value_id}'
  _ENUMSERVICE.methods_by_name['UpdateValue']._options = None
  _ENUMSERVICE.methods_by_name['UpdateValue']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002$\032\"/enums/{enum_id}/values/{value_id}'
  _ENUMSERVICE.methods_by_name['DescribeValue']._options = None
  _ENUMSERVICE.methods_by_name['DescribeValue']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002$\022\"/enums/{enum_id}/values/{value_id}'
  _ENUMSERVICE.methods_by_name['ListValues']._options = None
  _ENUMSERVICE.methods_by_name['ListValues']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\030\022\026/enums/{enum_id}/items'
  _ENUMSERVICE.methods_by_name['TranslateValue']._options = None
  _ENUMSERVICE.methods_by_name['TranslateValue']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002:\0328/enums/{enum_id}/values/{value_id}/translations/{locale}'
  _ENUMSERVICE.methods_by_name['DeleteTranslation']._options = None
  _ENUMSERVICE.methods_by_name['DeleteTranslation']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002:*8/enums/{enum_id}/values/{value_id}/translations/{locale}'
  _ENUMSERVICE.methods_by_name['ListTranslations']._options = None
  _ENUMSERVICE.methods_by_name['ListTranslations']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0021*//enums/{enum_id}/values/{value_id}/translations'
  _CREATEENUMINPUT._serialized_start=251
  _CREATEENUMINPUT._serialized_end=305
  _CREATEENUMOUTPUT._serialized_start=307
  _CREATEENUMOUTPUT._serialized_end=342
  _DELETEENUMINPUT._serialized_start=344
  _DELETEENUMINPUT._serialized_end=378
  _DELETEENUMOUTPUT._serialized_start=380
  _DELETEENUMOUTPUT._serialized_end=398
  _UPDATEENUMINPUT._serialized_start=401
  _UPDATEENUMINPUT._serialized_end=555
  _UPDATEENUMINPUT_PATCH._serialized_start=529
  _UPDATEENUMINPUT_PATCH._serialized_end=555
  _UPDATEENUMOUTPUT._serialized_start=557
  _UPDATEENUMOUTPUT._serialized_end=575
  _DESCRIBEENUMINPUT._serialized_start=577
  _DESCRIBEENUMINPUT._serialized_end=613
  _DESCRIBEENUMOUTPUT._serialized_start=615
  _DESCRIBEENUMOUTPUT._serialized_end=672
  _LISTENUMSINPUT._serialized_start=675
  _LISTENUMSINPUT._serialized_end=897
  _LISTENUMSINPUT_FILTER._serialized_start=780
  _LISTENUMSINPUT_FILTER._serialized_end=897
  _LISTENUMSOUTPUT._serialized_start=899
  _LISTENUMSOUTPUT._serialized_end=969
  _CREATEVALUEINPUT._serialized_start=971
  _CREATEVALUEINPUT._serialized_end=1045
  _CREATEVALUEOUTPUT._serialized_start=1047
  _CREATEVALUEOUTPUT._serialized_end=1084
  _DELETEVALUEINPUT._serialized_start=1086
  _DELETEVALUEINPUT._serialized_end=1139
  _DELETEVALUEOUTPUT._serialized_start=1141
  _DELETEVALUEOUTPUT._serialized_end=1160
  _UPDATEVALUEINPUT._serialized_start=1163
  _UPDATEVALUEINPUT._serialized_end=1387
  _UPDATEVALUEINPUT_PATCH._serialized_start=1313
  _UPDATEVALUEINPUT_PATCH._serialized_end=1387
  _UPDATEVALUEOUTPUT._serialized_start=1389
  _UPDATEVALUEOUTPUT._serialized_end=1408
  _DESCRIBEVALUEINPUT._serialized_start=1410
  _DESCRIBEVALUEINPUT._serialized_end=1481
  _DESCRIBEVALUEOUTPUT._serialized_start=1483
  _DESCRIBEVALUEOUTPUT._serialized_end=1543
  _LISTVALUESINPUT._serialized_start=1546
  _LISTVALUESINPUT._serialized_end=1803
  _LISTVALUESINPUT_FILTER._serialized_start=780
  _LISTVALUESINPUT_FILTER._serialized_end=897
  _LISTVALUESOUTPUT._serialized_start=1805
  _LISTVALUESOUTPUT._serialized_end=1877
  _TRANSLATEVALUEINPUT._serialized_start=1880
  _TRANSLATEVALUEINPUT._serialized_end=2009
  _TRANSLATEVALUEOUTPUT._serialized_start=2011
  _TRANSLATEVALUEOUTPUT._serialized_end=2033
  _DELETETRANSLATIONINPUT._serialized_start=2035
  _DELETETRANSLATIONINPUT._serialized_end=2110
  _DELETETRANSLATIONOUTPUT._serialized_start=2112
  _DELETETRANSLATIONOUTPUT._serialized_end=2137
  _LISTTRANSLATIONSINPUT._serialized_start=2140
  _LISTTRANSLATIONSINPUT._serialized_end=2352
  _LISTTRANSLATIONSINPUT_FILTER._serialized_start=2294
  _LISTTRANSLATIONSINPUT_FILTER._serialized_end=2352
  _LISTTRANSLATIONSOUTPUT._serialized_start=2354
  _LISTTRANSLATIONSOUTPUT._serialized_end=2444
  _ENUMSERVICE._serialized_start=2447
  _ENUMSERVICE._serialized_end=4529
# @@protoc_insertion_point(module_scope)
