# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import stats_pb2 as eolymp_dot_executor_dot_stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/executor/status.proto\x12\x0f\x65olymp.executor\x1a\x1b\x65olymp/executor/stats.proto\"\xde\t\n\x06Status\x12\x11\n\treference\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12*\n\x04type\x18\n \x01(\x0e\x32\x1c.eolymp.executor.Status.Type\x12\r\n\x05\x65rror\x18\x14 \x01(\t\x12\x0f\n\x07\x66\x61ilure\x18\x1e \x01(\t\x12)\n\x04runs\x18( \x03(\x0b\x32\x1b.eolymp.executor.Status.Run\x12\x11\n\tsignature\x18\x32 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\r\n\x05\x61gent\x18n \x01(\t\x1a\xd0\x07\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12\x32\n\x06status\x18\x02 \x01(\x0e\x32\".eolymp.executor.Status.Run.Status\x12\r\n\x05score\x18P \x01(\x02\x12\x0c\n\x04\x63ost\x18Q \x01(\x02\x12\x17\n\x0fwall_time_usage\x18\x33 \x01(\r\x12\x17\n\x0fwall_time_limit\x18= \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x34 \x01(\r\x12\x16\n\x0e\x63pu_time_limit\x18> \x01(\r\x12\x14\n\x0cmemory_usage\x18\x35 \x01(\x04\x12\x14\n\x0cmemory_limit\x18? \x01(\x04\x12\x11\n\texit_code\x18\x46 \x01(\r\x12\x0e\n\x06signal\x18G \x01(\r\x12\x11\n\tinput_url\x18\n \x01(\t\x12\x12\n\noutput_url\x18\x0b \x01(\t\x12\x12\n\nanswer_url\x18\x0c \x01(\t\x12\x12\n\nstderr_url\x18\x15 \x01(\t\x12+\n\x0b\x64\x65\x62ug_stats\x18Z \x01(\x0b\x32\x16.eolymp.executor.Stats\x12\x17\n\x0f\x63hecker_log_url\x18\x1f \x01(\t\x12\x1f\n\x17\x63hecker_wall_time_usage\x18  \x01(\r\x12\x1c\n\x14\x63hecker_memory_usage\x18! \x01(\x04\x12\x19\n\x11\x63hecker_exit_code\x18\" \x01(\r\x12-\n\rchecker_stats\x18# \x01(\x0b\x32\x16.eolymp.executor.Stats\x12\x1a\n\x12interactor_log_url\x18) \x01(\t\x12\"\n\x1ainteractor_wall_time_usage\x18* \x01(\r\x12\x1f\n\x17interactor_memory_usage\x18+ \x01(\x04\x12\x1c\n\x14interactor_exit_code\x18, \x01(\r\x12\x30\n\x10interactor_stats\x18- \x01(\x0b\x32\x16.eolymp.executor.Stats\"\xe4\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x11\n\rRUNTIME_ERROR\x10\x06\x12\x0c\n\x08\x45XECUTED\x10\x07\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x08\x12\x10\n\x0cWRONG_ANSWER\x10\t\x12\x18\n\x14VERIFICATION_FAILURE\x10\n\x12\x0b\n\x07SKIPPED\x10\x0b\x12\x17\n\x13INTERACTION_FAILURE\x10\x0c\"4\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _STATUS._serialized_start=79
  _STATUS._serialized_end=1325
  _STATUS_RUN._serialized_start=295
  _STATUS_RUN._serialized_end=1271
  _STATUS_RUN_STATUS._serialized_start=1043
  _STATUS_RUN_STATUS._serialized_end=1271
  _STATUS_TYPE._serialized_start=1273
  _STATUS_TYPE._serialized_end=1325
# @@protoc_insertion_point(module_scope)
